@@ -472,9 +472,10 @@ def getpen(color='black', fillcolor=None):
         'mb': (0, -SCR_H / 2)
     }
     t.ht()
-    t.pencolor(color)
     if fillcolor:
-        t.fillcolor(fillcolor)
+        t.color(color, fillcolor)
+    else:
+        t.color(color)
     t.speed(0)
     return t
 
